<?php

App::uses('AppComponent', 'Controller/Component');

class LoyaltyPointsComponent extends AppComponent {

	/**
	 * Component startup - check for the form being submitted
	 *
	 */
	public function startup(Controller $Controller) {
		if ($this->_controller->request->is('post') && ! empty($this->_controller->request->data['ApplyLoyaltyPoints'])) {

			$this->_setupCookie();
			$loyaltyPointCookie = $this->_controller->LoyaltyPointsCookie->read('LoyaltyPoints');

			if (! empty($loyaltyPointCookie)) {
				$this->_controller->Flash->fail(
					__('Your loyalty point balance has already been applied'),
					array(
						'key' => 'loyalty-points-flash'
					)
				);

				return false;
			}

			$pointModel = EvClassRegistry::init('EvLoyaltyPoints.Point');
			$data = $pointModel->totalPoints($this->_controller->Auth->user('User.id'));

			if (empty($data)) {
				$this->_controller->Flash->fail(
					__('You don\'t currently have any loyalty points to apply to your order.'),
					array(
						'key' => 'loyalty-point-flash'
					)
				);

				return false;
			}

			CakeSession::write('EvLoyaltyPoints.LoyaltyPoints', true);

			// dispatch event
			$this->_controller->getEventManager()->dispatch(
				new CakeEvent('EvLoyaltyPoints.Component.Points.usePoints', $this, array(

				))
			);

			CakeSession::write('EvLoyaltyPoints.discountApplied', true);

			$this->_controller->Flash->success(
				__('Your loyalty point balance has been appied to your order.'),
				array(
					'key' => 'discount-flash'
				)
			);
		}
		return true;
	}

	/**
	 * setup the loyalty code cookie
	 */
	protected function _setupCookie() {
		if (empty($this->_controller->LoyaltyPointsCookie)) {
			$this->_controller->LoyaltyPointsCookie = $this->_controller->loadComponent('EvLoyaltyPoints.LoyaltyPointsCookie');
		}
	}
}
